@@ -25,6 +25,15 @@ sub doInventory {
     # for each app, normalize the information, then add it to the inventory stack
     foreach my $app (keys %$apps){
         my $a = $apps->{$app};
+
+        next unless ref($a) eq 'HASH';
+
+# http://forge.fusioninventory.org/issues/716
+        if ($a->{'Get Info String'} && $a->{'Get Info String'} =~ /\S+, [C-Z]:\\\S+/) {
+            # Windows application found by Parallels
+            next;
+        }
+
         my $kind = $a->{'Kind'} ? $a->{'Kind'} : 'UNKNOWN';
         my $comments = '['.$kind.']';
         $inventory->addSoftware({
