@@ -9,7 +9,31 @@ sub isInventoryEnabled {
     return 1;
 }
 
-my %devices;
+my @devices;
+
+sub alreadyIn {
+    my ($vendorId, $productId, $serial) = @_;
+
+    foreach (@devices) {
+        if (
+            ($_->{vendorId} eq $vendorId)
+              &&
+            ($_->{productId} eq $productId)
+              &&
+            ($_->{serial} eq $serial)
+            ) {
+            return 1;
+        }
+    }
+
+    push @devices, {
+        vendorId => $vendorId,
+        productId => $productId,
+        serial => $serial
+    };
+
+    return;
+}
 
 sub doInventory {
     my $params = shift;
@@ -28,7 +52,9 @@ sub doInventory {
             $serial =~ s/&.*$//;
 
             next if $vendorId =~ /^0+$/;
-    
+
+            next if alreadyIn($vendorId, $productId, $serial);
+
             $inventory->addUSBDevice({
                 NAME => $Properties->{Name},
                 VENDORID => $vendorId,
