@@ -1,27 +1,23 @@
 package FusionInventory::Agent::XML::Response::Inventory;
 
 use strict;
-use FusionInventory::Agent::XML::Response;
-our @ISA = ('FusionInventory::Agent::XML::Response');
-
-sub new {
-    my ($class, @params) = @_;
-
-    my $self = $class->SUPER::new(@params);
-    bless ($self, $class);
-
-    return $self;
-}
+use warnings;
+use base 'FusionInventory::Agent::XML::Response';
 
 sub isAccountUpdated {
     my $self = shift;
 
     my $parsedContent = $self->getParsedContent();
-    if ($parsedContent && exists ($parsedContent->{RESPONSE}) && $parsedContent->{RESPONSE} =~ /^ACCOUNT_UPDATE$/) {
-	return 1;
-    }
 
-    0
+    if (
+        $parsedContent &&
+        exists $parsedContent->{RESPONSE} &&
+        $parsedContent->{RESPONSE} eq 'ACCOUNT_UPDATE'
+    ) {
+	return 1;
+    } else {
+	return 0;
+    }
 
 }
 
